==> onetbb-2021.5.0_1.darwin_10.ppc.tbz2: opt/local/lib/cmake/TBB/TBBTargets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TBB::tbb" for configuration "MacPorts"
set_property(TARGET TBB::tbb APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbb PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbb.12.5.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbb.12.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbb )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbb "${_IMPORT_PREFIX}/lib/libtbb.12.5.dylib" )

# Import target "TBB::tbbmalloc" for configuration "MacPorts"
set_property(TARGET TBB::tbbmalloc APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbbmalloc PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbbmalloc.2.5.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbbmalloc.2.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbbmalloc )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbbmalloc "${_IMPORT_PREFIX}/lib/libtbbmalloc.2.5.dylib" )

# Import target "TBB::tbbmalloc_proxy" for configuration "MacPorts"
set_property(TARGET TBB::tbbmalloc_proxy APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbbmalloc_proxy PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_MACPORTS "TBB::tbbmalloc"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbbmalloc_proxy.2.5.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbbmalloc_proxy.2.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbbmalloc_proxy )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbbmalloc_proxy "${_IMPORT_PREFIX}/lib/libtbbmalloc_proxy.2.5.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> onetbb-2021.9.0_0.darwin_10.ppc.tbz2: opt/local/lib/cmake/TBB/TBBTargets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TBB::tbb" for configuration "MacPorts"
set_property(TARGET TBB::tbb APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbb PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbb.12.9.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbb.12.dylib"
  )

list(APPEND _cmake_import_check_targets TBB::tbb )
list(APPEND _cmake_import_check_files_for_TBB::tbb "${_IMPORT_PREFIX}/lib/libtbb.12.9.dylib" )

# Import target "TBB::tbbmalloc" for configuration "MacPorts"
set_property(TARGET TBB::tbbmalloc APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbbmalloc PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbbmalloc.2.9.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbbmalloc.2.dylib"
  )

list(APPEND _cmake_import_check_targets TBB::tbbmalloc )
list(APPEND _cmake_import_check_files_for_TBB::tbbmalloc "${_IMPORT_PREFIX}/lib/libtbbmalloc.2.9.dylib" )

# Import target "TBB::tbbmalloc_proxy" for configuration "MacPorts"
set_property(TARGET TBB::tbbmalloc_proxy APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(TBB::tbbmalloc_proxy PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_MACPORTS "TBB::tbbmalloc"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtbbmalloc_proxy.2.9.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libtbbmalloc_proxy.2.dylib"
  )

list(APPEND _cmake_import_check_targets TBB::tbbmalloc_proxy )
list(APPEND _cmake_import_check_files_for_TBB::tbbmalloc_proxy "${_IMPORT_PREFIX}/lib/libtbbmalloc_proxy.2.9.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
